.. pygor3 documentation master file, created by
   sphinx-quickstart on Wed Jun 16 11:46:21 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pygor3's documentation!
==================================

.. toctree::
   :caption: Table of Contents
   :maxdepth: 2

   readme_link
   tutorial_2022
   pygor3_tutorial
   pygor3
   

..
   Pygor3 Tutorial
   ================
   .. toctre::
      :maxdepth: 2
   
      Tutorial
   


..
   Reference Guide
   ==============
   .. toctree::
   
      .. automodule:: pygor3.IgorIO
         :members:
      
      .. automodule:: pygor3.IgorSqliteDB
         :members:
      
      .. automodule:: pygor3.imgt
         :members:
   
   
   
   
   Indices and tables
   ==================
   
   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
